@@ -1,6 +1,6 @@
 import sys
 
-import pymouse
+import pymouse  # type: ignore
 
 
 def PyMouse():
@@ -9,7 +9,7 @@ def PyMouse():
     """
     # Quick, turn off printing!
     class dummyStream:
-        """ dummyStream behaves like a stream but does nothing. """
+        """dummyStream behaves like a stream but does nothing."""
 
         def __init__(self):
             pass
