@@ -12,7 +12,7 @@ import logging
 from time import sleep
 
 from PIL import ImageChops, ImageFilter, ImageStat
-from pykeyboard import PyKeyboard
+from pykeyboard import PyKeyboard  # type: ignore
 
 from discogui.imglog import img_log, img_log_rects
 from discogui.imgutil import focus_wnd, getbbox, grab
@@ -79,13 +79,13 @@ def tab_rectangles():
 
 
 def tab_rect_pair(img_orig, im_next):
-    """
-    """
+    """ """
     img_diff = ImageChops.difference(img_orig, im_next)
     img_log(img_diff, "img_diff")
 
     # can be dotted -> filter + enhance color
-    img_diff_filtered = img_diff.filter(ImageFilter.MaxFilter(5))
+    # Problem: close buttons -> filter value sohuld be low
+    img_diff_filtered = img_diff.filter(ImageFilter.MaxFilter(3))
     img_diff_filtered = img_diff_filtered.point(lambda x: 255 * bool(x))
     img_log(img_diff_filtered, "img_diff_filtered")
 
@@ -112,7 +112,7 @@ def tab_rect_pair(img_orig, im_next):
             color2 = sum(img_diff_filtered.getpixel(p2))
             ls += [int(bool(color1 + color2))]
 
-        if not 0 in ls:
+        if 0 not in ls:
             log.debug("split pos not found")
             return
         i = ls.index(0)
