@@ -6,7 +6,7 @@ from discogui.taborder import tab_rectangles
 
 def test_notab():
     with SmartDisplay() as disp:
-        with EasyProcess("xmessage hi"):
+        with EasyProcess(["xmessage", "hi"]):
             disp.waitgrab()
             ls = tab_rectangles()
             assert len(ls) == 0
@@ -14,7 +14,7 @@ def test_notab():
 
 def test_gmessage():
     with SmartDisplay() as disp:
-        with EasyProcess("gmessage -buttons x,y,z hi"):
+        with EasyProcess(["gmessage", "-buttons", "x,y,z", "hi"]):
             disp.waitgrab()
             ls = tab_rectangles()
             assert len(ls) == 4
